import Oid.*;
import javax.swing.*;
import javax.swing.event.*;
import java.awt.*;
import java.awt.event.*;

/**
 * This class displays a panel with a single label that describes an 
 * instance of <code>FiniteFieldMatroid</code>
 *
 * @author Robert J. Kingan and Sandra R. Kingan
 * @date 19 Sept 2001
 * @version 3.0
 *
 * Copyright 2004 Robert J. Kingan and Sandra R. Kingan
 * 
 * This file is part of Oid.
 *
 * Oid is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * Oid is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Oid; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
public class FiniteFieldMatroidDisplayPanel extends JPanel
{
  /** 
   * constructs a display panel for the matroid <code>m</code>
   */
  public FiniteFieldMatroidDisplayPanel(FiniteFieldMatroid m)
  {
    setLayout(new BorderLayout());
    JLabel caption;
    JTextField textField;
    JPanel horizPanel;
    JPanel vertPanel = new JPanel();
    vertPanel.setLayout(new BoxLayout(vertPanel, BoxLayout.Y_AXIS));

    // matroid name
    horizPanel = new JPanel();
    horizPanel.setLayout(new BoxLayout(horizPanel, BoxLayout.X_AXIS));
    caption = new JLabel("Name:");
    textField = new JTextField();
    textField.setText(m.getName());
    textField.setEditable(false);
    horizPanel.add(caption);
    horizPanel.add(textField);
    vertPanel.add(horizPanel);

    // matroid field size
    horizPanel = new JPanel();
    horizPanel.setLayout(new BoxLayout(horizPanel, BoxLayout.X_AXIS));
    caption = new JLabel("Field Size:");
    textField = new JTextField();
    textField.setText(String.valueOf(m.getField().getFieldSize()));
    textField.setEditable(false);
    horizPanel.add(caption);
    horizPanel.add(textField);
    vertPanel.add(horizPanel);

    // matroid size
    horizPanel = new JPanel();
    horizPanel.setLayout(new BoxLayout(horizPanel, BoxLayout.X_AXIS));
    caption = new JLabel("Size:");
    textField = new JTextField();
    textField.setText(String.valueOf(m.getSize()));
    textField.setEditable(false);
    horizPanel.add(caption);
    horizPanel.add(textField);
    vertPanel.add(horizPanel);

    // matroid rank
    horizPanel = new JPanel();
    horizPanel.setLayout(new BoxLayout(horizPanel, BoxLayout.X_AXIS));
    caption = new JLabel("Rank:");
    textField = new JTextField();
    textField.setText(String.valueOf(m.getRank()));
    textField.setEditable(false);
    horizPanel.add(caption);
    horizPanel.add(textField);
    vertPanel.add(horizPanel);

    JTextArea matrixArea = new JTextArea(10, 40);
    matrixArea.setEditable(false);
    Font f = matrixArea.getFont();
    matrixArea.setFont(new Font("Monospaced", Font.PLAIN, f.getSize()));
    matrixArea.setText(FiniteFieldMatroidFormatter.displayWithLabels(m));
    
    JScrollPane scrollPane = 
	new JScrollPane(matrixArea, 
			JScrollPane.VERTICAL_SCROLLBAR_AS_NEEDED,
			JScrollPane.HORIZONTAL_SCROLLBAR_AS_NEEDED);

    add(vertPanel, BorderLayout.NORTH);
    add(scrollPane, BorderLayout.CENTER);
  }

  /**
   * allows class to be tested from the command line
   *
   * @param arg array of strings with command-line arguments; ignored
   */
  public static void main(String[] arg)
  {
    PGFactory factory = new PGFactory(3, 9);
    FiniteFieldMatroid m = 
      new FiniteFieldMatroid(factory.getProjectiveSpace());
    JFrame frame = new JFrame("FiniteFieldMatroidDisplayPanel");
    FiniteFieldMatroidDisplayPanel panel = 
      new FiniteFieldMatroidDisplayPanel(m);

    frame.addWindowListener(new WindowAdapter() {
	public void windowClosing(WindowEvent e) {
	  System.exit(0);
	}
      });

    frame.getContentPane().add(panel);
    frame.pack();
    frame.setVisible(true);
  }
}
