import Oid.*;
import javax.swing.*;
import java.awt.*;
import java.awt.event.*;
import java.util.*;

/** 
 * Panel that displays properties of a <code>LinearSpace</code>
 *
 * @author Robert J. Kingan and Sandra R. Kingan
 * @date 19 April 2002
 * @version 3.0
 *
 * Copyright 2004 Robert J. Kingan and Sandra R. Kingan
 * 
 * This file is part of Oid.
 *
 * Oid is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * Oid is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Oid; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
public class LinearSpaceDisplayPanel extends JPanel
{
  //
  // private data members
  //
  private LinearSpace mLinearSpace;
  private JTextArea mTextArea;
  
  /** 
   * constructs panel with specified <code>LinearSpace</code>
   * 
   * @param linearSpace space to display
   */
  public LinearSpaceDisplayPanel(LinearSpace linearSpace)
  {
    mLinearSpace = linearSpace;
    setupPanel(10, 30);
  }

  /**
   * constructs panel with specified <code>LinearSpace</code>, text area
   * height and width
   *
   * @param linearSpace space to display
   * @param height text area height
   * @param width text area width
   * @throws IllegalArgumentException if <code>height</code> or 
   * <code>width</code> is invalid
   */
  public LinearSpaceDisplayPanel(LinearSpace linearSpace, 
				 int height, int width)
    throws IllegalArgumentException
  {
    if ((height <= 0) || (width <= 0)) {
      throw new IllegalArgumentException("Invalid height and/or width");
    }
    mLinearSpace = linearSpace;
    setupPanel(height, width);
  }

  private void setupPanel(int height, int width) 
  {
    String lf = System.getProperty("line.separator");
    setLayout(new BorderLayout());

    JPanel colPanel = new JPanel();
    colPanel.setLayout(new BoxLayout(colPanel, BoxLayout.Y_AXIS));
    
    JLabel label;
    label = new JLabel("Name: " + mLinearSpace.getName());
    colPanel.add(label);
    label = new JLabel("Size: " + mLinearSpace.getSize());
    colPanel.add(label);
    label = new JLabel("Rank: " + mLinearSpace.getRank());
    colPanel.add(label);
    label = new JLabel("Lines:");
    colPanel.add(label);
    add(colPanel, BorderLayout.NORTH);

    mTextArea = new JTextArea(height, width);
    Font f = mTextArea.getFont();
    mTextArea.setFont(new Font("Monospaced", Font.PLAIN, f.getSize()));
    mTextArea.setEditable(false);
    
    String allLines = new String();
    Vector lines = new Vector(mLinearSpace.getLineVector());
    for (Iterator pb = lines.iterator(); pb.hasNext(); ) {
      allLines += ((Subset)pb.next()).toStringNoFmt();
      allLines += lf;
    }
    mTextArea.setText(allLines);
    JScrollPane scrollPane =
      new JScrollPane(mTextArea,
                      JScrollPane.VERTICAL_SCROLLBAR_AS_NEEDED,
                      JScrollPane.HORIZONTAL_SCROLLBAR_AS_NEEDED);
    add(scrollPane, BorderLayout.CENTER);
  }

  /**
   * allows this class to be tested from the command line
   *
   * @param arg array of command line arguments; ignored
   */
  public static void main(String[] arg)
  {
    JFrame frame = new JFrame("LinearSpaceDisplayPanel");
    LinearSpaceDisplayPanel panel;

    PGFactory factory = new PGFactory(3, 2);
    FiniteFieldMatroid matroid = 
      new FiniteFieldMatroid(factory.getProjectiveSpace());
    LinearSpace linearSpace = new LinearSpace(matroid);

    panel = new LinearSpaceDisplayPanel(linearSpace);
    frame.addWindowListener(new WindowAdapter() {
	public void windowClosing(WindowEvent e) {
	  System.exit(0);
	}
      });

    frame.getContentPane().add(panel);
    frame.pack();
    frame.setVisible(true);    
  }
}
