package Oid;
import java.util.*;

/**
 * Classes which implement Combiner generate an object from a collection
 * of objects.
 *
 * @author Robert J. Kingan
 * @date 4 Oct 2001
 *
 * Copyright 2004 Robert J. Kingan and Sandra R. Kingan
 * 
 * This file is part of Oid.
 *
 * Oid is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * Oid is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Oid; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
public interface Combiner
{
  /**
   * sets the reference collection for this constructor 
   * 
   * @param ref reference collection
   */
  public void setCollection(Collection ref) 
    throws IllegalArgumentException;

  /**
   * returns the reference collection for this constructor 
   * 
   * @return reference collection
   */
  public Object getCollection();

  /**
   * returns the constructed object from the reference collection 
   *
   * @return contructed object
   */
  public Object getConstruction();

  /**
   * returns a description of the algorithm used for the construction 
   *
   * @return description
   */
  public String getAlgorithmDescription();

  /**
   * returns the algorithm's name 
   *
   * @return algorithm name
   */
  public String getName();
}
