package Oid;
import java.util.*;

/**
 * Classes which implement SingleConstructor generate an object from a 
 * reference object, with an optional integer parameter.
 *
 * @author Robert J. Kingan and Sandra R. Kingan
 * @date 4 Oct 2001
 * @version 3.0
 *
 * Copyright 2004 Robert J. Kingan and Sandra R. Kingan
 * 
 * This file is part of Oid.
 *
 * Oid is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * Oid is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Oid; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
public interface SingleConstructor
{
  /** 
   * sets the reference object for this constructor 
   *
   * @param ref reference object
   * @throws IllegalArgumentException if ref is not of the right type
   */
  public void setInstance(Object ref) 
    throws IllegalArgumentException;

  /** 
   * returns the reference object for this constructor 
   * 
   * @return reference to object passed to this algorithm
   */
  public Object getInstance();

  /** 
   * indicates whether the algorithm requires a parameter
   *
   * @return boolean answer
   */
  public boolean requiresParameter();

  /** 
   * sets the algorithm's parameters
   *
   * @param parameters String containing parameters for algorithm
   * @throws IllegalArgumentException if parameters are not correct
   */
  public void setParameters(String parameters)
    throws IllegalArgumentException;

  /**
   * returns the prompt to display when asking the user to enter the 
   * parameters required for the algorithm
   * 
   * @return String with prompt
   */
  public String getPrompt();

  /** 
   * returns the algorithm's parameters
   *
   * @return String with parameters
   */
  public String getParameters();

  /** 
   * returns the constructed object from the reference object
   *
   * @return object constructed by algorithm
   */
  public Object getConstruction();

  /** 
   * returns a description of the algorithm used for the construction
   *
   * @return string description of algorithm
   */
  public String getAlgorithmDescription();

  /** 
   * returns this algorithm's name
   *
   * @return string with algorithm's name
   */
  public String getName();

}
