package Oid;
import java.util.*;

/**
 * Classes which implement SubsetLister generate a collection of subsets
 * having a specified property for an object.  They can also generate a
 * Vector containing indexed collections of Subsets.  The property which
 * provides the index is returned by getArrayIndexName.  Another method,
 * getSubsetCountChain, simply returns a Vector with the counts of the
 * Subsets at various indices.
 *
 * @author Robert J. Kingan and Sandra R. Kingan
 * @date 4 Oct 2001
 * @version 3.0
 *
 * Copyright 2004 Robert J. Kingan and Sandra R. Kingan
 * 
 * This file is part of Oid.
 *
 * Oid is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * Oid is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Oid; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
public interface SubsetLister
{
  /** 
   * sets the reference object for this SubsetLister 
   *
   * @param arg reference object
   * @throws IllegalArgumentException if <code>arg</code> isn't the right type
   */
  public void setInstance(Object arg)
    throws IllegalArgumentException;

  /** 
   * returns the reference object for this SubsetLister
   *
   * @return reference object
   */
  public Object getInstance();

  /** 
   * generates a list of the relevant Subsets for the reference object
   *
   * @return <code>Collection</code> of subsets
   * @throws NullPointerException if argument for algorithm isn't set
   */
  public Collection getSubsetList()
    throws NullPointerException;

  /** 
   * generates a Vector containing indexed collections of Subsets for 
   * the reference object
   *
   * @return <code>Vector</code> of subset collections
   * @throws NullPointerException if argument for algorithm isn't set
   */
  public Vector getSubsetListVector()
    throws NullPointerException;

  /**  
   * generates a Vector containing the number of Subsets at each index
   * for the reference object
   *
   * @return <code>Vector</code> of subset counts
   * @throws NullPointerException if argument for algorithm isn't set
   */
  public Vector getSubsetCountChain()
    throws NullPointerException;

  /**
   * returns the name of the property by which the subsets are indexed
   *
   * @return name of indexed property
   * @throws NullPointerException if argument for algorithm isn't set
   */
  public String getArrayIndexName()
    throws NullPointerException;

  /** 
   * returns a description of the algorithm used to generate subsets
   *
   * @return algorithm description
   */
  public String getAlgorithmDescription();

  /** 
   * returns the name of the algorithm
   *
   * @return algorithm name
   */
  public String getName();
}
