import Oid.*;
import javax.swing.*;
import java.awt.*;
import java.awt.event.*;
import java.util.*;

/**
 * This subclass of <code>JPanel</code> displays text on a non-editable
 * <code>JTextArea</code>.
 *
 * @author Robert J. Kingan and Sandra R. Kingan
 * @date 4 Nov 2001
 * @version 3.0
 *
 * Copyright 2004 Robert J. Kingan and Sandra R. Kingan
 * 
 * This file is part of Oid.
 *
 * Oid is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * Oid is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Oid; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
public class ReadOnlyTextPanel extends JPanel
{
  //
  // private data members
  // 
  private JTextArea mTextArea;
  
  /** 
   * default constructor 
   */
  public ReadOnlyTextPanel()
  {
    setupPanel(10, 30);
  }

  /**
   * sets up panel with indicated text area height and width
   *
   * @param height height of text area
   * @param width width of text area
   */
  public ReadOnlyTextPanel(int height, int width)
  {
    if ((height <= 0) || (width <= 0)) {
      throw new IllegalArgumentException("Invalid height and/or width");
    }
    setupPanel(height, width);
  }

  private void setupPanel(int height, int width) 
  {
    setLayout(new BorderLayout());
    mTextArea = new JTextArea(height, width);
    Font f = mTextArea.getFont();
    mTextArea.setFont(new Font("Monospaced", Font.PLAIN, f.getSize()));
    mTextArea.setEditable(false);
    JScrollPane scrollPane =
      new JScrollPane(mTextArea,
                      JScrollPane.VERTICAL_SCROLLBAR_AS_NEEDED,
                      JScrollPane.HORIZONTAL_SCROLLBAR_AS_NEEDED);
    add(scrollPane, BorderLayout.CENTER);
  }

  /** 
   * allows the client to set the text on the display 
   *
   * @param text text to display
   */
  public void setText(String text)
  {
    mTextArea.setText(text);
  }

  /** 
   * returns the text from the display 
   * 
   * @return text from display
   */
  public String getText() 
  {
    return mTextArea.getText();
  }

  /**
   * allows this class to be tested from the command line
   *
   * @param arg array of command line arguments; strings are concatenated
   * with spaces and displayed on text area
   */
  public static void main(String[] arg)
  {
    JFrame frame = new JFrame("ReadOnlyTextPanel");
    ReadOnlyTextPanel panel;
    StringBuffer sb = new StringBuffer();

    for (int i=0; i<arg.length; i++) {
      sb.append(arg[i]);
      sb.append(" ");
    }

    panel = new ReadOnlyTextPanel();
    panel.setText(sb.toString());
    frame.addWindowListener(new WindowAdapter() {
	public void windowClosing(WindowEvent e) {
	  System.exit(0);
	}
      });

    frame.getContentPane().add(panel);
    frame.pack();
    frame.setVisible(true);    
  }
}
