import Oid.*;
import javax.swing.*;
import javax.swing.event.*;
import java.awt.*;
import java.awt.event.*;
import java.util.*;

/**
 * Subclass of <code>JMenuItem</code> that also stores a reference 
 * to a <code>Task</code>.
 *
 * @author Robert J. Kingan and Sandra R. Kingan
 * @date 02 Nov 2001
 * @version 3.0
 *
 * Copyright 2004 Robert J. Kingan and Sandra R. Kingan
 * 
 * This file is part of Oid.
 *
 * Oid is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * Oid is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Oid; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
public class TaskMenuItem extends JMenuItem
{
  //
  // private data members
  //
  private Task mTask;

  //
  // constructors 
  //

  /** 
   * Creates a TaskMenuItem with no set text or icon, with the passed Task
   * reference.
   *
   * @param t <code>Task</code> to associate with menu item
   */
  TaskMenuItem(Task t)
  {
    mTask = t;
    setText(mTask.getDescription());
  }

  /**
   * Creates a menuItem with an icon.
   *
   * @param icon <code>Icon</code> to display on menu item
   */
  TaskMenuItem(Icon icon)
  {
    super(icon);
  }

  /**
   * Creates a TaskMenuItem with an icon and with the passed Task reference.
   *
   * @param t <code>Task</code> to associate with menu item
   * @param icon <code>Icon</code> to display on menu item
   */
  TaskMenuItem(Icon icon, Task t)
  {
    super(icon);
    mTask = t;
    setText(mTask.getDescription());
  }

  /**
   * Creates a TaskMenuItem with text.
   *
   * @param text Text to display on menu item
   */
  TaskMenuItem(String text)
  {
    super(text);
  }

  /**
   * Creates a TaskMenuItem with text and with the passed Task reference
   * 
   * @param text Text to display on menu item
   * @param t <code>Task</code> to associate with menu item
   */
  TaskMenuItem(String text, Task t)
  {
    super(text);
    mTask = t;
  }

  /**
   * Creates a TaskMenuItem with the supplied text and icon.
   *
   * @param text text to display on menu item
   * @param icon <code>icon</code> to display on menu item
   */
  TaskMenuItem(String text, Icon icon)
  {
    super(text, icon);
  }

  /**
   * Creates a TaskMenuItem with the supplied text and icon and with the
   * passed Task reference.
   *
   * @param text text to display on menu item
   * @param icon <code>icon</code> to display on menu item
   * @param t <code>Task</code> to associate with menu item
   */
  TaskMenuItem(String text, Icon icon, Task t)
  {
    super(text, icon);
    mTask = t;
  }

  /**
   * Creates a menuItem with the specified text and keyboard mnemonic.
   *
   * @param text text to display on menu item
   * @param mnemonic keyboard mnemonic for menu item
   */
  TaskMenuItem(String text, int mnemonic)
  {
    super(text, mnemonic);
  }

  /**
   * Creates a menuItem with the specified text and keyboard mnemonic, and
   * with the specified Task reference.
   *
   * @param text text to display on menu item
   * @param mnemonic keyboard mnemonic for menu item
   * @param t <code>Task</code> to associate with menu item
   */
  TaskMenuItem(String text, int mnemonic, Task t)
  {
    super(text, mnemonic);
    mTask = t;
  }

  /** 
   * Sets a reference to the TaskMenuItem's Task 
   *
   * @param t <code>Task</code> to associate with menu item
   */
  public void setTask(Task t)
  {
    mTask = t;
  }

  /** 
   * Returns a reference to the TaskMenuItem's Task 
   *
   * @return <code>Task</code> associated with menu item
   */
  public Task getTask()
  {
    return mTask;
  }
}
