import Oid.*;
import java.util.*;
import javax.swing.*;
import java.awt.*;
import java.awt.event.*;

/** 
 * <code>VisConnectivity</code> computes and outputs the value of the
 * matroid connectivity function for every nontrivial subset X of the
 * ground set of a matroid M.  This formula is given by
 *
 * r(X) + r(E-X) - r(M).
 *
 * @author Robert J. Kingan and Sandra R. Kingan
 * @date 11 June 2003
 * @version 3.0
 *
 * Copyright 2004 Robert J. Kingan and Sandra R. Kingan
 * 
 * This file is part of Oid.
 *
 * Oid is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * Oid is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Oid; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
public class VisConnectivity implements Visualization
{
  private String mLF;

  public VisConnectivity()
  {
    mLF = new String("\n");
  }

  /** 
   * generates a visualization of the passed object and returns it as
   * a JPanel
   */
  public JPanel getVisualization(Object obj)
    throws IllegalArgumentException
  {
    Matroid M;
    Subset X, Xc;
    int r, n;
    int i, cf;
    SubsetEnumeration se;
    StringBuffer txt = new StringBuffer();

    if (!(obj instanceof Matroid)) {
      throw new IllegalArgumentException("Requires a matroid");
    }

    M = (Matroid)obj;
    r = M.getRank();
    n = M.getSize();

    for (i=1; i<n; i++) {
      txt.append("Size: " + String.valueOf(i) + mLF);
      for (se = new SubsetEnumeration(n, i); se.hasMoreElements(); ) {
	X = (Subset)se.nextElement();
	Xc = X.complement();
	cf = M.subsetRank(X) + M.subsetRank(Xc) - r;
	txt.append(X.toString(true));
	txt.append(" ");
	txt.append(String.valueOf(cf));
	txt.append(mLF);
      }
    }

    ReadOnlyTextPanel panel = new ReadOnlyTextPanel();
    panel.setText(txt.toString());
    return panel;
  }


  /**
   * returns the visualization's name 
   */
  public String getName()
  {
    return new String("Matroid Connectivity Function");
  }

  /**
   * returns a string describing the visualization
   */
  public String getDescription()
  {
    StringBuffer answer = new StringBuffer();
    return answer.toString();
  }
}
