import Oid.*;
import javax.swing.*;
import java.awt.*;
import java.awt.event.*;
import java.util.*;

/** 
 * VisFiniteFieldContractions generates all of the single-element
 * extensions of a GF(p)-representable matroid, and displays their
 * circuit, cocircuit, independent set and coindependent set chains.
 *
 * @author Robert J. Kingan and Sandra R. Kingan
 * @date 6 Nov 2001
 * @version 3.0
 *
 * Copyright 2004 Robert J. Kingan and Sandra R. Kingan
 * 
 * This file is part of Oid.
 *
 * Oid is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * Oid is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Oid; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
public class VisFiniteFieldContractions implements Visualization
{
  //
  // private data members 
  //
  // mWidth determines width of fields when outputting matroids
  private int    mWidth;
  // mField has (mWidth) spaces
  private String mField;
  private String LF;

  /** 
   * generates a visualization of the passed object and returns it as
   * a JPanel
   */
  public JPanel getVisualization(Object obj)
    throws IllegalArgumentException
  {
    if (!(obj instanceof FiniteFieldMatroid)) {
      throw new IllegalArgumentException("GF(p) matroid needed");
    }

    if (!((FiniteFieldMatroid)obj).inStandardForm()) {
      throw new IllegalArgumentException("Matroid must be in standard form");
    }

    LF = "\n"; 
    FiniteFieldMatroid base = (FiniteFieldMatroid)obj;
    mWidth = String.valueOf(base.getField().getFieldSize()).length() + 2;
    int n = base.getSize();
    int r = base.getRank();
    FiniteField calc = base.getField();
    int i,j;
    FiniteFieldMatroid contraction;
    boolean found;
    StringBuffer ansBuf = new StringBuffer("");

    // loop through elements of matroid
    for (i=0; i<n; i++) {
      contraction = base.getContraction(i);
      ansBuf.append(FiniteFieldMatroidFormatter.displayWithLabels
		    (contraction));
      ansBuf.append(LF + LF);
    }

    ReadOnlyTextPanel answer = new ReadOnlyTextPanel();
    answer.setText(ansBuf.toString());
    return answer;
  }

  /**
   * returns the visualization's name 
   */
  public String getName()
  {
    return new String("GF(p) single-element contraction viewer");
  }

  /**
   * returns a string describing the visualization
   */
  public String getDescription()
  {
    return new String("VisFiniteFieldContractions generates all of the single-element contractions of  a GF(p)-representable matroid, and displays their circuit, cocircuit, independent set and coindependent set chains.");
  }
}
