import Oid.*;
import javax.swing.*;
import java.awt.*;
import java.awt.event.*;
import java.util.*;

/** 
 * This class uses Padma Gunturi's <code>DisplayGeom</code> class to
 * display the geometric representation of a matroid within the Oid
 * user interface.
 * 
 * @author Robert J. Kingan and Sandra R. Kingan
 * @date 16 April 2002
 * @version 3.0
 *
 * Copyright 2004 Robert J. Kingan and Sandra R. Kingan
 * 
 * This file is part of Oid.
 *
 * Oid is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * Oid is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Oid; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
public class VisGeomRepr implements Visualization
{
  /** 
   * generates a visualization of the passed object and returns it as
   * a JPanel
   */
  public JPanel getVisualization(Object obj)
    throws IllegalArgumentException
  {
    JPanel panel = (JPanel)null;
    LinearSpace ls;

    if (!((obj instanceof Matroid) || (obj instanceof LinearSpace))) {
      throw new IllegalArgumentException("Requires a matroid");
    }

    if (obj instanceof LinearSpace) {
      try {
	panel = new DisplayGeom(obj);
      }
      catch (Exception e) {
	throw new InternalError(e.toString());
      }
    }
    else if (obj instanceof FiniteFieldMatroid) {
      if (((FiniteFieldMatroid)obj).getRank() > 3) {
	throw new IllegalArgumentException("Rank is too high");
      }
      try {
	panel = new DisplayGeom(obj);
      }
      catch (Exception e) {
	throw new InternalError(e.toString());
      }
    }
    else {
      ls = new LinearSpace((Matroid)obj);
      try {
	panel = new DisplayGeom(ls);
      }
      catch (Exception e) {
	throw new InternalError(e.toString());
      }
    }

    return panel;

//  	  try {
//  		  if (!(obj instanceof Matroid) && !(obj instanceof LinearSpace)) {
//        throw new IllegalArgumentException("Requires a matroid");
//        }

    
//      JPanel panel = new DisplayGeom(obj);
//  	return panel;
//  	  }
//  	catch (Exception e) {
//        throw new InternalError(e.toString());
//      }
  }

  
  /**
   * returns the visualization's name 
   */
  public String getName()
  {
    return new String("Geometric representation viewer");
  }

  /**
   * returns a string describing the visualization
   */
  public String getDescription()
  {
    return new String("VisGeomRepr generates the geometric representation of the matroid.");
  }
}
