import Oid.*;
import javax.swing.*;
import java.awt.*;
import java.awt.event.*;

/** 
 * an object implementing the <code>Visualization</code> interface has
 * a method called getVisualization which accepts an
 * <code>Object</code> (and may throw an
 * <code>IllegalArgumentException</code> if the object is not of the
 * right class) and returns a <code>JPanel</code> (or, most
 * frequently, some subclass of <code>JPanel</code>) which can be
 * displayed
 *
 * @author Robert J. Kingan and Sandra R. Kingan
 * @date 6 Nov 2001
 * @version 3.0
 *
 * Copyright 2004 Robert J. Kingan and Sandra R. Kingan
 * 
 * This file is part of Oid.
 *
 * Oid is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * Oid is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Oid; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
public interface Visualization
{
  /** 
   * generates a visualization of the passed object and returns it as
   * a JPanel
   * 
   * @param obj object to visualize
   * @throws IllegalArgumentException if <code>obj</code> is invalid
   */
  public JPanel getVisualization(Object obj)
    throws IllegalArgumentException;

  /**
   * returns the visualization's name 
   *
   * @return name of visualization
   */
  public String getName();

  /**
   * returns a string describing the visualization
   * 
   * @return description of visualization
   */
  public String getDescription();
}
